optimize_function

Function optimize_function 

pub fn optimize_function(func: &HirFunction) -> HirFunction
Run all optimization passes on a function.

Runs constant folding, dead branch removal, and temporary elimination in a fixed-point loop until no more changes are made or MAX_ITERATIONS is reached.