pub struct TranspilationCache { /* private fields */ }Expand description
Transpilation cache for avoiding re-transpilation of unchanged files.
Uses SHA-256 hashing to detect file changes and supports disk persistence. Provides 10-20x speedup on cache hits.
Examples
use decy_core::{TranspilationCache, ProjectContext, transpile_file};
use std::path::Path;
let mut cache = TranspilationCache::new();
let path = Path::new("src/main.c");
let context = ProjectContext::new();
// First transpilation - cache miss
let result = transpile_file(path, &context)?;
cache.insert(path, &result);
// Second access - cache hit (if file unchanged)
if let Some(cached) = cache.get(path) {
println!("Cache hit! Using cached result");
}Implementations
Sourceimpl TranspilationCache
impl TranspilationCache
Sourcepub fn with_directory(cache_dir: &Path) -> Self
pub fn with_directory(cache_dir: &Path) -> Self
Create a cache with a specific directory for persistence.
Sourcepub fn compute_hash(&self, path: &Path) -> Result<String>
pub fn compute_hash(&self, path: &Path) -> Result<String>
Compute SHA-256 hash of a file’s content.
Returns a 64-character hex string.
Sourcepub fn insert(&mut self, path: &Path, transpiled: &TranspiledFile)
pub fn insert(&mut self, path: &Path, transpiled: &TranspiledFile)
Insert a transpiled file into the cache.
Sourcepub fn get(&mut self, path: &Path) -> Option<&TranspiledFile>
pub fn get(&mut self, path: &Path) -> Option<&TranspiledFile>
Get a cached transpilation result if the file hasn’t changed.
Returns None if:
- File is not in cache
- File content has changed
- Any dependency has changed
Sourcepub fn statistics(&self) -> CacheStatistics
pub fn statistics(&self) -> CacheStatistics
Get cache statistics.